@@ -1,6 +1,6 @@
 /**
  * @file  iminfo.c
- * @copyright Copyright (C) 2019 Michał Bąbik
+ * @copyright Copyright (C) 2019-2020 Michał Bąbik
  *
  * This file is part of Wall Changer.
  *
@@ -81,8 +81,10 @@ imageinfo_new (void)
 
     ii_res = calloc (1, sizeof (ImageInfo));
 
-    if (ii_res == NULL)
-        return NULL;
+    if (ii_res == NULL) {
+        fputs ("Alloc error\n", stderr);
+        exit (EXIT_FAILURE);
+    }
 
     imageinfo_init (ii_res);
 
@@ -101,13 +103,8 @@ imageinfo_new_from_file (const char *s_fname)
     int        i_w     = 0;    /* Image width */
     int        i_h     = 0;    /* Image height */
 
-    if (s_fname == NULL)
-        return NULL;
-
     ii_info = imageinfo_new ();
-
     imageinfo_set_full_name (ii_info, s_fname);
-
     s_p = strrchr (s_fname, '/');
 
     if (s_p == NULL) {
@@ -117,10 +114,8 @@ imageinfo_new_from_file (const char *s_fname)
     else {
         s_p++;
         imageinfo_set_file_name (ii_info, s_p);
-
-        s_path = str_ndup (s_fname, (size_t) (s_p - s_fname));
+        s_path = strndup (s_fname, (size_t) (s_p - s_fname));
         imageinfo_set_file_path (ii_info, s_path);
-
         free (s_path);
     }
 
@@ -194,16 +189,20 @@ file_paths_to_imageinfo (GSList *gsl_files1)
 {
     GSList    *gsl_iinfo = NULL; /* Result ImageInfo list */
     GSList    *gsl_files = NULL; /* Pointer to file list */
-    ImageInfo *ii_info;
 
     gsl_files = gsl_files1;
 
     while (gsl_files != NULL) {
 
-        ii_info = imageinfo_new_from_file ((char *) gsl_files->data);
+        char *s_fn = (char *) gsl_files->data;
 
-        if (imageinfo_get_height (ii_info) > 0)
-            gsl_iinfo = g_slist_append (gsl_iinfo, ii_info);
+        if (s_fn != NULL) {
+
+            ImageInfo *ii_info = imageinfo_new_from_file (s_fn);
+
+            if (imageinfo_get_height (ii_info) > 0)
+                gsl_iinfo = g_slist_append (gsl_iinfo, ii_info);
+        }
 
         gsl_files = gsl_files->next;
     }
@@ -220,7 +219,7 @@ imageinfo_set_full_name (ImageInfo  *ii_info,
     if (ii_info->s_full_path != NULL)
         free (ii_info->s_full_path);
 
-    ii_info->s_full_path = str_dup (s_name);
+    ii_info->s_full_path = strdup (s_name);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -242,7 +241,7 @@ imageinfo_set_file_name (ImageInfo  *ii_info,
     if (ii_info->s_file_name != NULL)
         free (ii_info->s_file_name);
 
-    ii_info->s_file_name = str_dup (s_name);
+    ii_info->s_file_name = strdup (s_name);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -264,7 +263,7 @@ imageinfo_set_file_path (ImageInfo  *ii_info,
     if (ii_info->s_file_path != NULL)
         free (ii_info->s_file_path);
 
-    ii_info->s_file_path = str_dup (s_name);
+    ii_info->s_file_path = strdup (s_name);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -322,15 +321,12 @@ imageinfo_set_wxh (ImageInfo *ii_info,
                    const int  i_w,
                    const int  i_h)
 {
-    char s_tmp[40]; /* Temp string, I think it is long enough */
+    char s_tmp[41]; /* Temp string, I think it is long enough */
 
     memset (s_tmp, 0, sizeof(s_tmp));
-
-    sprintf (s_tmp, "%dx%d", i_w, i_h);
-
+    snprintf (s_tmp, 41, "%dx%d", i_w, i_h);
     create_resize ((void**) &ii_info->s_width_height, strlen (s_tmp)+1,
                    sizeof (char));
-
     strcpy (ii_info->s_width_height, s_tmp);
 }
 /*----------------------------------------------------------------------------*/
