@@ -1,6 +1,6 @@
 /**
  * @file  rwdt.c
- * @copyright Copyright (C) 2019 Michał Bąbik
+ * @copyright Copyright (C) 2019-2020 Michał Bąbik
  *
  * This file is part of Wall Changer.
  *
@@ -69,9 +69,7 @@ read_file_data (const char  *s_fname,
         fclose (f_file);
         return NULL;
     }
-
     create_resize ((void**) &s_buff, (size_t) l_size+1, sizeof (char));
-
     /* copy the file into the buffer */
     ul_res = fread (s_buff, 1, (size_t) l_size, f_file);
 
@@ -102,14 +100,16 @@ read_file_data_hash (const char  *s_fname,
 
     s_buff = read_file_data (s_fname, i_err);
 
-
     if (*i_err != ERR_OK) {
         *i_hash = 0;
         return NULL;
     }
 
-    //printf ("bff %s\n", s_buff);
-    *i_hash = hash (s_buff);
+    if (s_buff == NULL)
+        *i_hash = 0;
+    else
+        *i_hash = hash (s_buff);
+
     *i_err = ERR_OK;
 
     return s_buff;
@@ -134,9 +134,7 @@ save_file_data (const char *s_fname,
         return ERR_FILE;
     }
     ul_size = strlen(s_buff);
-
     ul_res = fwrite (s_buff , sizeof(char), ul_size, f_file);
-
     fclose (f_file);
 
     if (ul_res != ul_size) {
