@@ -1,6 +1,6 @@
 /**
  * @file  treev.c
- * @copyright Copyright (C) 2019 Michał Bąbik
+ * @copyright Copyright (C) 2019-2020 Michał Bąbik
  *
  * This file is part of Wall Changer.
  *
@@ -39,10 +39,10 @@
  * @param[in]  ii_info  Data in ImageInfo object
  * @return     none
  *
- * @fn  static void liststore_add_item (GtkWidget       *gw_list,
- *                                      const ImageInfo *ii_info)
+ * @fn  static void treeview_add_item     (GtkWidget       *gw_tview,
+                                           const ImageInfo *ii_info)
  * @brief      Insert single data item to GtkListStore.
- * @param[out] gw_list  GtkWidget with GtkListStore to insert data
+ * @param[out] gw_tview    TreeView in which data should be added
  * @param[in]  ii_info  data in ImageInfo object
  * @return     none
  *
@@ -52,27 +52,17 @@
  * @param[out] gw_tview    TreeView in which data should be replaced
  * @param[in]  gsl_iinfo1  List with ImageInfo objects with data.
  * @return     none
- *
- * @fn  static void liststore_add_items (GtkWidget *gw_list,
- *                                       GSList    *gsl_iinfo1)
- * @brief  Insert multiple data items to GtkListStore.
- * @param[out] gw_list     GtkWidget with GtkListStore to insert data
- * @param[in]  gsl_iinfo1  List with ImageInfo objects with data.
- * @return     none
  */
 /*----------------------------------------------------------------------------*/
 static void liststore_set_item    (GtkListStore    *gls_list,
                                    GtkTreeIter     *gti_iter,
                                    const ImageInfo *ii_info);
 
-static void liststore_add_item    (GtkWidget       *gw_list,
+static void treeview_add_item     (GtkWidget       *gw_tview,
                                    const ImageInfo *ii_info);
 
 static void treeview_replace_data (GtkWidget       *gw_tview,
                                    GSList          *gsl_iinfo1);
-
-static void liststore_add_items   (GtkWidget       *gw_list,
-                                   GSList          *gsl_iinfo1);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set data in GtkListStore.
@@ -96,17 +86,16 @@ liststore_set_item (GtkListStore    *gls_list,
  * @brief  Insert single data item to GtkListStore.
  */
 static void
-liststore_add_item (GtkWidget       *gw_list,
-                    const ImageInfo *ii_info)
+treeview_add_item (GtkWidget       *gw_tview,
+                   const ImageInfo *ii_info)
 {
     GtkListStore *gls_store;
     GtkTreeIter   gti_iter;
 
     gls_store = GTK_LIST_STORE (gtk_tree_view_get_model (
-                GTK_TREE_VIEW (gw_list)));
+                GTK_TREE_VIEW (gw_tview)));
 
     gtk_list_store_append (gls_store, &gti_iter);
-
     liststore_set_item (gls_store, &gti_iter, ii_info);
 }
 /*----------------------------------------------------------------------------*/
@@ -126,13 +115,11 @@ treeview_replace_data (GtkWidget *gw_tview,
     gboolean      b_res     = FALSE;
 
     gsl_iinfo = gsl_iinfo1;
-
     gtm_model = gtk_tree_view_get_model (GTK_TREE_VIEW (gw_tview));
     gls_list  = GTK_LIST_STORE (gtm_model);
-
-    ui_icnt = g_slist_length (gsl_iinfo);
-    ui_mcnt = (uint32_t) gtk_tree_model_iter_n_children (
-            GTK_TREE_MODEL (gls_list), NULL);
+    ui_icnt   = g_slist_length (gsl_iinfo);
+    ui_mcnt   = (uint32_t) gtk_tree_model_iter_n_children (
+                GTK_TREE_MODEL (gls_list), NULL);
     
     if (ui_icnt == ui_mcnt) {
 
@@ -149,30 +136,11 @@ treeview_replace_data (GtkWidget *gw_tview,
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Insert multiple data items to GtkListStore.
- */
-static void
-liststore_add_items (GtkWidget *gw_list,
-                     GSList    *gsl_iinfo1)
-{
-    GSList *gsl_iinfo = NULL; /* Temp ItemInfo list */
-
-    gsl_iinfo = gsl_iinfo1;
-
-    while (gsl_iinfo != NULL) {
-
-        liststore_add_item (gw_list, gsl_iinfo->data);
-
-        gsl_iinfo = gsl_iinfo->next;
-    }
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Insert multiple data items to GtkListStore.
+ * @brief  Insert multiple data items to GtkTreeView.
  */
 void
-liststore_add_items_glist (GtkWidget *gw_list,
-                           GList     *gl_files)
+treeview_add_items_glist (GtkWidget *gw_tview,
+                          GList     *gl_files)
 {
     GList *gl_fl = NULL; /* Temp ItemInfo list */
 
@@ -180,27 +148,24 @@ liststore_add_items_glist (GtkWidget *gw_list,
 
     while (gl_fl != NULL) {
 
-        const char *s_fn = (const char *) gl_fl->data;
-
-        ImageInfo *ii_info = imageinfo_new_from_file (s_fn);
+        const char *s_fn    = (const char *) gl_fl->data;
+        ImageInfo  *ii_info = imageinfo_new_from_file (s_fn);
 
         if (ii_info != NULL) {
 
-            liststore_add_item (gw_list, ii_info);
-
+            treeview_add_item (gw_tview, ii_info);
             imageinfo_free (ii_info);
         }
-
         gl_fl = gl_fl->next;
     }
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Insert multiple data items to GtkListStore.
+ * @brief  Insert multiple data items to GtkTreeView.
  */
 void
-liststore_add_items_gslist (GtkWidget *gw_list,
-                            GSList    *gl_files)
+treeview_add_items_gslist (GtkWidget *gw_tview,
+                           GSList    *gl_files)
 {
     GSList *gl_fl = NULL; /* Temp ItemInfo list */
 
@@ -208,40 +173,31 @@ liststore_add_items_gslist (GtkWidget *gw_list,
 
     while (gl_fl != NULL) {
 
-        const char *s_fn = (const char *) gl_fl->data;
-
-        ImageInfo *ii_info = imageinfo_new_from_file (s_fn);
+        const char *s_fn    = (const char *) gl_fl->data;
+        ImageInfo  *ii_info = imageinfo_new_from_file (s_fn);
 
         if (ii_info != NULL) {
 
-            liststore_add_item (gw_list, ii_info);
-
+            treeview_add_item (gw_tview, ii_info);
             imageinfo_free (ii_info);
         }
-
         gl_fl = gl_fl->next;
     }
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Insert multiple data items to GtkListStore.
+ * @brief  Insert multiple data items to GtkTreeView.
  */
 void
-liststore_add_items_settlist (GtkWidget       *gw_list,
-                              const SettList  *sl_walls)
+treeview_add_items_settlist (GtkWidget       *gw_tview,
+                             const SettList  *sl_walls)
 {
-    Setting    *st_wall;
-    const char *s_fn      = NULL;
-    uint32_t    ui_cnt    = 0;
-    uint32_t    i         = 0;
+    uint32_t ui_cnt = stlist_get_length (sl_walls);
 
-    ui_cnt = stlist_get_length (sl_walls);
+    for (uint32_t i = 0; i < ui_cnt; ++i) {
 
-    for (i = 0; i < ui_cnt; ++i) {
-
-        st_wall = stlist_get_setting_at_pos (sl_walls, i);
-
-        s_fn = setting_get_string (st_wall);
+        Setting    *st_wall = stlist_get_setting_at_pos (sl_walls, i);
+        const char *s_fn    = setting_get_string (st_wall);
 
         if (s_fn != NULL) {
 
@@ -249,8 +205,7 @@ liststore_add_items_settlist (GtkWidget       *gw_list,
 
             if (ii_info != NULL) {
 
-                liststore_add_item (gw_list, ii_info);
-
+                treeview_add_item (gw_tview, ii_info);
                 imageinfo_free (ii_info);
             }
         }
@@ -344,7 +299,6 @@ treeview_sort_list (GtkWidget *gw_tview)
     GSList *gsl_iinfo = NULL; /* TreeView item list */
 
     gsl_iinfo = treeview_get_data (gw_tview);
-
     gsl_iinfo = imageinfo_sort (gsl_iinfo);
 
     treeview_replace_data (gw_tview, gsl_iinfo);
@@ -519,8 +473,7 @@ create_tview (GtkWidget **gw_tview)
     GtkTreeSelection *gts_sele;
 
     *gw_tview = gtk_tree_view_new ();
-
-    gts_sele = gtk_tree_view_get_selection (GTK_TREE_VIEW (*gw_tview));
+    gts_sele  = gtk_tree_view_get_selection (GTK_TREE_VIEW (*gw_tview));
     gtk_tree_selection_set_mode (gts_sele, GTK_SELECTION_MULTIPLE);
 
     gcr_render = gtk_cell_renderer_text_new ();
