@@ -1,6 +1,6 @@
 /** 
  * @file  wchanger.c
- * @copyright Copyright (C) 2019 Michał Bąbik
+ * @copyright Copyright (C) 2019-2020 Michał Bąbik
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
  *
  * Automatic wallpaper changer
  *
- * @date December 22, 2019
+ * @date January 14, 2020
  *
- * @version 1.3.5
+ * @version 1.3.6
  * 
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -233,12 +233,6 @@ DialogData {
  * @param[in,out] app      Pointer to GtkApplication
  * @param[in,out] dd_data  DialogData object with settings and widget data
  * @return        none
- *
- * @fn static void shutdown (GtkApplication *app, DialogData *dd_data)
- * @brief      Application shutdown signal.
- * @param      app      Pointer to GtkApplication
- * @param[out] dd_data  Pointer to DialogData object
- * @return     none
  */
 /*----------------------------------------------------------------------------*/
 static uint32_t    get_wallpaper_ch_interval   (const DialogData  *dd_data);
@@ -313,9 +307,6 @@ static void        create_settings_widget      (GtkWidget        **gw_widget,
 static void        activate                    (GtkApplication    *app,
                                                 DialogData        *dd_data);
 /*----------------------------------------------------------------------------*/
-static void        shutdown                    (GtkApplication    *app,
-                                                DialogData        *dd_data);
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Get wallpaper change minutes interval from widgets
  */
@@ -350,7 +341,6 @@ set_wallpaper_ch_interval (DialogData    *dd_data,
 
         /* If value can be hours set combobox to hours */
         gtk_combo_box_set_active (GTK_COMBO_BOX (dd_data->gw_inter_combo), 1);
-
         ui_tmp /= 60;
     }
     else {
@@ -379,24 +369,20 @@ get_wallpaper_list (GtkWidget *gw_view,
 
     /* get ImageInfo list of TreeView files */
     gsl_iinfo1 = treeview_get_data (gw_view);
+    gsl_iinfo  = gsl_iinfo1;
+    st_sett    = setting_new_array (get_setting_name (SETTING_WALL_ARRAY));
 
-    gsl_iinfo = gsl_iinfo1;
-
-    st_sett = setting_new_array (get_setting_name (SETTING_WALL_ARRAY));
     stlist_insert_setting (st_list, st_sett);
 
     while (gsl_iinfo != NULL) {
 
         ii_info = gsl_iinfo->data;
-
-        s_val = ii_info->s_full_path;
-        s_name = str_name_with_number (get_setting_name (SETTING_WALL_ARRAY),
-                                       ul_no++);
-
+        s_val   = ii_info->s_full_path;
+        s_name  = str_name_with_number (get_setting_name (SETTING_WALL_ARRAY),
+                                        ul_no++);
         st_sett = setting_new_string (s_val, s_name);
 
         free (s_name);
-
         stlist_insert_setting_to_array (st_list, st_sett,
                                         get_setting_name (SETTING_WALL_ARRAY));
         gsl_iinfo = gsl_iinfo->next;
@@ -411,7 +397,7 @@ static void
 set_wallpaper_list (const SettList *sl_walls,
                     GtkWidget      *gw_view)
 {
-    liststore_add_items_settlist (gw_view, sl_walls);
+    treeview_add_items_settlist (gw_view, sl_walls);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -526,7 +512,7 @@ widgets_set_settings (DialogData     *dd_data,
  * @brief  Add images button pressed.
  */
 static void
-event_add_img_pressed (GtkWidget  *widget,
+event_add_img_pressed (GtkWidget  *widget __attribute__ ((unused)),
                        DialogData *dd_data)
 {
     GSList *gsl_files = NULL; /* List with files from dialog */
@@ -537,8 +523,7 @@ event_add_img_pressed (GtkWidget  *widget,
     /* Add items to TreeView */
     if (gsl_files != NULL) {
 
-        liststore_add_items_gslist (dd_data->gw_view, gsl_files);
-
+        treeview_add_items_gslist (dd_data->gw_view, gsl_files);
         g_slist_free_full (gsl_files, g_free);
     }
 }
@@ -547,46 +532,33 @@ event_add_img_pressed (GtkWidget  *widget,
  * @brief  Add images from folder button pressed.
  */
 static void
-event_add_img_dir_pressed (GtkWidget  *widget,
+event_add_img_dir_pressed (GtkWidget  *widget __attribute__ ((unused)),
                            DialogData *dd_data)
 {
     char       *s_folder = NULL;  /* Selecred directory name */
     GList      *gl_files = NULL;  /* Images in directory */
-    GHashTable *gh_exts;          /* List of extensions */
-
-    /* Append to list extensions of image types supported by GdkPixbuf */
-    gh_exts = get_pbuf_exts_to_ghash ();
 
     /* Run directory select dialog and get selected directory name */
     s_folder = add_images_folder_dialog (dd_data->gw_window);
 
     if (s_folder != NULL) {
         /* Scan directory for files and append them to file list */
-        gl_files = get_directory_content_glist (s_folder);
+        gl_files = get_dir_content_filter_images (s_folder);
 
         if (gl_files != NULL) {
-            /* Filter file list of files with extensions that are not
-             * supported by GdkPixbuf */
-            gl_files = glist_filter_by_extensions_list (gl_files, gh_exts);
-
-            if (gl_files != NULL) {
-                /* Add items to TreeView */
-                liststore_add_items_glist (dd_data->gw_view, gl_files);
-
-                g_list_free_full (gl_files, g_free);
-            }
+            /* Add items to TreeView */
+            treeview_add_items_glist (dd_data->gw_view, gl_files);
+            g_list_free_full (gl_files, g_free);
         }
-
         g_free (s_folder);
     }
-    g_hash_table_destroy (gh_exts);
 }
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Remove items from list pressed.
  */
 static void
-event_rem_from_list_pressed (GtkWidget *widget,
+event_rem_from_list_pressed (GtkWidget *widget __attribute__ ((unused)),
                              GtkWidget *gw_tview)
 {
     treeview_remove_selected (gw_tview);
@@ -596,7 +568,7 @@ event_rem_from_list_pressed (GtkWidget *widget,
  * @brief  Move up items pressed.
  */
 static void
-event_move_up_pressed (GtkWidget *widget,
+event_move_up_pressed (GtkWidget *widget __attribute__ ((unused)),
                        GtkWidget *gw_tview)
 {
     treeview_move_up (gw_tview);
@@ -606,7 +578,7 @@ event_move_up_pressed (GtkWidget *widget,
  * @brief  Move down items pressed.
  */
 static void
-event_move_down_pressed (GtkWidget *widget,
+event_move_down_pressed (GtkWidget *widget __attribute__ ((unused)),
                          GtkWidget *gw_tview)
 {
     treeview_move_down (gw_tview);
@@ -616,7 +588,7 @@ event_move_down_pressed (GtkWidget *widget,
  * @brief  Sort wallpaper list button pressed.
  */
 static void
-event_sort_list_pressed (GtkWidget *widget,
+event_sort_list_pressed (GtkWidget *widget __attribute__ ((unused)),
                          GtkWidget *gw_tview)
 {
     treeview_sort_list (gw_tview);
@@ -626,7 +598,7 @@ event_sort_list_pressed (GtkWidget *widget,
  * @brief  Remove duplicates button pressed.
  */
 static void
-event_rem_dupl_pressed (GtkWidget *widget,
+event_rem_dupl_pressed (GtkWidget *widget __attribute__ ((unused)),
                         GtkWidget *gw_tview)
 {
     treeview_remove_duplicates (gw_tview);
@@ -636,7 +608,7 @@ event_rem_dupl_pressed (GtkWidget *widget,
  * @brief  Set wallpaper button pressed.
  */
 static void
-event_set_wallpaper_pressed (GtkWidget  *widget,
+event_set_wallpaper_pressed (GtkWidget  *widget __attribute__ ((unused)),
                              DialogData *dd_data)
 {
     GtkTreeSelection *gts_sele;
@@ -674,15 +646,14 @@ event_set_wallpaper_pressed (GtkWidget  *widget,
  * @brief  Save settings button pressed.
  */
 static void
-event_save_settings_pressed (GtkWidget  *widget,
+event_save_settings_pressed (GtkWidget  *widget __attribute__ ((unused)),
                              DialogData *dd_data)
 {
     SettList *st_list;
     int       i_err = 0;
 
     st_list = widgets_get_settings (dd_data);
-
-    i_err = settings_check_update_file (st_list, dd_data->s_cfg_file);
+    i_err   = settings_check_update_file (st_list, dd_data->s_cfg_file);
 
     stlist_free (st_list);
 
@@ -696,7 +667,7 @@ event_save_settings_pressed (GtkWidget  *widget,
  * @brief  About Wall Changer
  */
 static void
-event_about_app_pressed (GtkWidget  *widget)
+event_about_app_pressed (GtkWidget  *widget __attribute__ ((unused)))
 {
     about_app_dialog (APP_VERSION);
 }
@@ -707,7 +678,7 @@ event_about_app_pressed (GtkWidget  *widget)
 static void
 event_img_list_activated (GtkTreeView       *tree_view,
                           GtkTreePath       *path,
-                          GtkTreeViewColumn *column,
+                          GtkTreeViewColumn *column __attribute__ ((unused)),
                           GtkWidget         *gw_img_prev)
 {
     GtkTreeModel *gtm_model;
@@ -789,7 +760,7 @@ event_interval_changed (GtkSpinButton *spin_button,
  */
 static gboolean
 event_on_delete (GtkWidget  *window,
-                 GdkEvent   *event,
+                 GdkEvent   *event __attribute__ ((unused)),
                  DialogData *dd_data)
 {
     GtkWidget *dialog;
@@ -803,9 +774,7 @@ event_on_delete (GtkWidget  *window,
     gtk_window_get_size (GTK_WINDOW (window), &i_w, &i_h);
 
     st_list = widgets_get_settings (dd_data);
-
-    s_buff = settings_check_update (st_list, dd_data->s_cfg_file, &i_err);
-
+    s_buff  = settings_check_update (st_list, dd_data->s_cfg_file, &i_err);
     stlist_free (st_list);
 
     if (i_err != ERR_OK) {
@@ -818,17 +787,13 @@ event_on_delete (GtkWidget  *window,
                                          GTK_MESSAGE_QUESTION,
                                          GTK_BUTTONS_YES_NO,
             "Settings changed, do you want to save them ?");
-
         gtk_window_set_title (GTK_WINDOW (dialog), "Settings changed");
 
         i_res = gtk_dialog_run (GTK_DIALOG (dialog));
-
         gtk_widget_destroy (dialog);
 
         if (i_res == GTK_RESPONSE_YES) {
-
             i_err = settings_update_file (s_buff, dd_data->s_cfg_file);
-
             if (i_err != ERR_OK) {
                 message_dialog_error (GTK_WINDOW (window),
                                       err_get_message (i_err));
@@ -878,10 +843,10 @@ create_image_button (const char   *s_label,
 
     gw_btn = gtk_button_new ();
 
-    if (strcmp (s_label, "") != 0)
+    if (s_label != NULL && strcmp (s_label, "") != 0)
         gtk_button_set_label (GTK_BUTTON (gw_btn), s_label);
 
-    if (strcmp (s_hint, "") != 0)
+    if (s_hint != NULL && strcmp (s_hint, "") != 0)
         gtk_widget_set_tooltip_text (gw_btn, s_hint);
 
     gd_pix = get_image (i_but);
@@ -904,7 +869,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
 
     *gw_widget = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
 
-    gw_button = create_image_button ("", "Add images", W_ICON_ADD);
+    gw_button = create_image_button (NULL, "Add images", W_ICON_ADD);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -912,7 +877,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_add_img_pressed),
                       dd_data);
-    gw_button = create_image_button ("", "Add images from folder",
+    gw_button = create_image_button (NULL, "Add images from folder",
                                      W_ICON_ADD_DIR);
     g_signal_connect (gw_button,
                       "clicked",
@@ -921,7 +886,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
-    gw_button = create_image_button ("", "Remove images", W_ICON_REMOVE);
+    gw_button = create_image_button (NULL, "Remove images", W_ICON_REMOVE);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -929,7 +894,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_rem_from_list_pressed),
                       dd_data->gw_view);
-    gw_button = create_image_button ("", "Move up", W_ICON_UP);
+    gw_button = create_image_button (NULL, "Move up", W_ICON_UP);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -937,7 +902,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_move_up_pressed),
                       dd_data->gw_view);
-    gw_button = create_image_button ("", "Move down", W_ICON_DOWN);
+    gw_button = create_image_button (NULL, "Move down", W_ICON_DOWN);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -945,7 +910,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_move_down_pressed),
                       dd_data->gw_view);
-    gw_button = create_image_button ("", "Sort images", W_ICON_SORT);
+    gw_button = create_image_button (NULL, "Sort images", W_ICON_SORT);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -953,7 +918,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_sort_list_pressed),
                       dd_data->gw_view);
-    gw_button = create_image_button ("", "Remove duplicates", W_ICON_DUPL);
+    gw_button = create_image_button (NULL, "Remove duplicates", W_ICON_DUPL);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -961,7 +926,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_rem_dupl_pressed),
                       dd_data->gw_view);
-    gw_button = create_image_button ("", "Set wallpaper", W_ICON_SCREEN);
+    gw_button = create_image_button (NULL, "Set wallpaper", W_ICON_SCREEN);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -969,7 +934,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_set_wallpaper_pressed),
                       dd_data);
-    gw_button = create_image_button ("", "Save settings", W_ICON_FLOPPY);
+    gw_button = create_image_button (NULL, "Save settings", W_ICON_FLOPPY);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
@@ -977,14 +942,14 @@ create_buttons_widget (GtkWidget  **gw_widget,
                       "clicked",
                       G_CALLBACK (event_save_settings_pressed),
                       dd_data);
-    gw_button = create_image_button ("", "About Wall Changer", W_ICON_INFO);
+    gw_button = create_image_button (NULL, "About Wall Changer", W_ICON_INFO);
     gtk_box_pack_start (GTK_BOX (*gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect (gw_button,
                       "clicked",
                       G_CALLBACK (event_about_app_pressed), NULL);
-    gw_button = create_image_button ("", "Exit app", W_ICON_EXIT);
+    gw_button = create_image_button (NULL, "Exit app", W_ICON_EXIT);
     g_signal_connect_swapped (gw_button,
                               "clicked",
                               G_CALLBACK (gtk_window_close),
@@ -1001,24 +966,24 @@ static void
 create_settings_widget (GtkWidget **gw_widget,
                         DialogData *dd_data)
 {
-    GtkWidget     *gw_button_random;
-    GtkWidget     *gw_button_selectlast;
-    GtkWidget     *gw_command_entry;
-    GtkWidget     *gw_spinbutton;
-    GtkAdjustment *ga_adjustment;
-    GtkWidget     *gw_command_label;
-    GtkWidget     *gw_interval_label;
-    GtkWidget     *gw_time_combo;
-    const char    *s_markup = NULL;
+    GtkWidget     *gw_random_button;     /* Random image GtkCheckButton */
+    GtkWidget     *gw_button_selectlast; /* Set last used GtkCheckButton */
+    GtkWidget     *gw_command_label;     /* Wallpaper set cmd GtkLabel */
+    GtkWidget     *gw_command_entry;     /* Wallpaper set cmd GtkEntry */
+    GtkWidget     *gw_interval_label;    /* Time interval GtkLabel */
+    GtkWidget     *gw_spinbutton;        /* Time interval GtkSpinButton */
+    GtkAdjustment *ga_adjustment;        /* Time interval GtkAdjustment */
+    GtkWidget     *gw_time_combo;        /* Time interval GtkComboBoxText*/
+    const char    *s_markup = NULL;      /* String for markups */
 
     /* Random wallpaper change button */
     s_markup = "When <b>enabled</b> wallpaper images will be selected "
         "randomly.\n"
         "When <b>disabled</b> wallpapers will be set in the same order as "
         "they appear on the list";
-    gw_button_random = gtk_check_button_new ();
-    gtk_widget_set_tooltip_markup (gw_button_random, s_markup);
-    gtk_button_set_label (GTK_BUTTON (gw_button_random),
+    gw_random_button = gtk_check_button_new ();
+    gtk_widget_set_tooltip_markup (gw_random_button, s_markup);
+    gtk_button_set_label (GTK_BUTTON (gw_random_button),
                           "Random wallpaper change");
 
     /* Select last used wallpaper button */
@@ -1059,7 +1024,7 @@ create_settings_widget (GtkWidget **gw_widget,
                   G_CALLBACK (event_interval_changed), dd_data);
 
     /* Setting pointers in DialogData */
-    dd_data->gw_random      = gw_button_random;
+    dd_data->gw_random      = gw_random_button;
     dd_data->gw_lastused    = gw_button_selectlast;
     dd_data->gw_command     = gw_command_entry;
     dd_data->gw_interval    = gw_spinbutton;
@@ -1072,14 +1037,14 @@ create_settings_widget (GtkWidget **gw_widget,
 
     /* Packing button for random change */
     gtk_grid_attach (GTK_GRID (*gw_widget),
-                     gw_button_random, 0, 0, 1, 1);
+                     gw_random_button, 0, 0, 1, 1);
     gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
-                             gw_button_selectlast, gw_button_random,
+                             gw_button_selectlast, gw_random_button,
                              GTK_POS_BOTTOM, 1, 1);
 
     /* Packing background set command */
     gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
-                             gw_command_label, gw_button_random,
+                             gw_command_label, gw_random_button,
                              GTK_POS_RIGHT, 1, 1);
     gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
                              gw_command_entry, gw_command_label,
@@ -1128,7 +1093,7 @@ activate (GtkApplication *app,
         g_application_quit (G_APPLICATION (app));
         return;
     }
-
+    
     /* Image preview widget */
     gw_img_prev = gtk_image_new ();
 
@@ -1168,6 +1133,9 @@ activate (GtkApplication *app,
     gtk_box_pack_start (GTK_BOX (gw_box_prev),
                         gw_img_prev,
                         FALSE, FALSE, 4);
+    gtk_box_pack_start (GTK_BOX (gw_box_prev),
+                        create_preview_label (),
+                        FALSE, FALSE, 4);
 
     /* Pack file list, button box, separatr and wallpaper preview */
     gw_box_list_btns = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
@@ -1235,16 +1203,6 @@ activate (GtkApplication *app,
     gtk_widget_show_all (gw_window);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Application shutdown signal.
- */
-static void
-shutdown (GtkApplication *app,
-          DialogData     *dd_data)
-{
-    //free (dd_data->s_cfg_file);
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief Main function.
  *
@@ -1264,14 +1222,9 @@ main (int    argc,
 
     app = gtk_application_new ("org.nongnu.WallChanger",
                                G_APPLICATION_FLAGS_NONE);
-
     g_signal_connect (app, "activate", G_CALLBACK (activate), &dd_data);
-    g_signal_connect (app, "shutdown", G_CALLBACK (shutdown), &dd_data);
-
     g_set_application_name (APP_NAME);
-
     status = g_application_run (G_APPLICATION (app), argc, argv);
-
     g_object_unref (app);
 
     return status;
